@@ -33,6 +33,7 @@ from unify.apiutils import remove_special
 from unify.assetaccess import AssetAccess
 from unify.graph import Graph
 from unify.hierarchies import Hierarchy
+from unify.helpers.SingleOrg import single_org
 
 
 class ApiManager:
@@ -40,7 +41,7 @@ class ApiManager:
     Class to interact with import and export dataset methods
     """
 
-    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING)):
+    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING), org_id=None):
         try:
 
             self.properties = props
@@ -49,7 +50,7 @@ class ApiManager:
 
             self.orgs = OrgAdmin(cluster=cluster, props=self.properties)
 
-            self.templates = Templates(cluster=cluster, props=self.properties)
+            self.templates = Templates(cluster=cluster, props=self.properties, org_id=org_id)
 
             self.pipelines = Pipelines(cluster=cluster, props=self.properties)
 
@@ -65,10 +66,13 @@ class ApiManager:
 
             self.pipelines.evergreen_enabled = self.evergreen_enabled
 
+            self.org_id = org_id
+
         except Exception as error:
             raise error
 
-    def delete_source(self, org_id, source_id):
+    @single_org
+    def delete_source(self, org_id=None, *, source_id):
 
         return self.sources.delete_source(
             org_id=org_id,
@@ -78,6 +82,7 @@ class ApiManager:
     def query_graph(self, org, graph, query, json_format):
         """
         Create a cypher query request
+
         :param org: Org where the graph to be queried is stored
         :param graph: Graph uuid to be queried
         :param query: String that contains cypher query
@@ -92,17 +97,21 @@ class ApiManager:
             json_format=json_format
         )
 
-    def graphs_list(self, org):
+    @single_org
+    def graphs_list(self, org_id=None):
         """
         Return the list of graphs on a given org
-        :param org: Org ID that wants to be queried
+
+        :param org_id: Org ID that wants to be queried
         :return: Json list with graph on the org
         """
-        return self.graphs.get_graphs_list(org_id=org)
+        return self.graphs.get_graphs_list(org_id=org_id)
 
-    def regular_pipeline_duplicate(self, org_id, pipeline_id, new_name):
+    @single_org
+    def regular_pipeline_duplicate(self, org_id=None, *, pipeline_id, new_name):
         """
         Duplicate a given pipeline on the same org
+
         :param org_id: Org id where the pipeline is stored
         :param pipeline_id: Pipeline id that will be duplicated
         :param new_name: The new pipeline's name
@@ -172,7 +181,8 @@ class ApiManager:
 
         raise Exception("Unsupported type of source to be imported")
 
-    def export_source(self, org_id, dataset_ids):
+    @single_org
+    def export_source(self, org_id=None, *, dataset_ids):
         """
         Retrieves the content of a dataset
 
@@ -205,7 +215,8 @@ class ApiManager:
             content=content
         )
 
-    def dataset_list(self, org_id):
+    @single_org
+    def dataset_list(self, org_id=None):
         """
         Retrieves metadata for all datasets on a given org
 
@@ -224,7 +235,8 @@ class ApiManager:
         except Exception as error:
             raise error
 
-    def pipeline_list(self, org_id):
+    @single_org
+    def pipeline_list(self, org_id=None):
         """
         Retrieves metadata for all pipelines on a given org
 
@@ -264,8 +276,8 @@ class ApiManager:
 
     def export_function(self, org_id, function):
         """
-        Create a json structure with all the components needed
-        to import a function
+        Create a json structure with all the components needed to import a function
+
         :param org_id:
         :param function:
         :return:
@@ -556,16 +568,17 @@ class ApiManager:
 
         return list(errors)
 
-    def create_export_source_file(self, org_id, pipeline_id, skip):
+    @single_org
+    def create_export_source_file(self, org_id=None, *, pipeline_id, skip):
         """
         This methods creates the export file
 
         :param org_id: Org id to export the dataset
-        :type org_id: int or str
+        :type org_id: str
         :param pipeline_id: Pipeline id
         :type pipeline_id: int or str
         :param skip: skip
-        :type skip: bool
+        :type skip: list
         :return:
         """
 
@@ -621,7 +634,8 @@ class ApiManager:
 
         return json.dumps(result_data)
 
-    def create_pipeline_export_data(self, org_id, pipeline_id, skip):
+    @single_org
+    def create_pipeline_export_data(self, org_id=None, *, pipeline_id, skip):
         """
         Create all the necessary data to export a pipeline
 
@@ -863,7 +877,8 @@ class ApiManager:
 
         return pipeline_data, list(errors)
 
-    def proceses_importing_pipeline_file(self, org_id, content, skip, handleduplicates="clone", function=False,
+    @single_org
+    def proceses_importing_pipeline_file(self, org_id=None, *, content, skip, handleduplicates="clone", function=False,
                                          loaded=False):
         """
         Process pipeline importing.
@@ -873,7 +888,7 @@ class ApiManager:
         :param content: Pipeline import content
         :type content: str
         :param skip: variable to skip datasets or templates
-        :type skip: bool
+        :type skip: list
         :param handleduplicates: Boolean variable to decide what to do with duplicate pipeline
         :type handleduplicates: bool, optional
         :return:
@@ -1086,17 +1101,19 @@ class ApiManager:
         except Exception as error:
             raise error
 
-    def get_all_hierarchies_display(self, org):
+    @single_org
+    def get_all_hierarchies_display(self, org_id=None):
         """
         Method to retrieve all the organization on a given org
-        :param org: Organization id where the org is stored
+
+        :param org_id: Organization id where the org is stored
         :return:
         """
         columns = [
             "id", "name"
         ]
 
-        raw_data = self.get_all_hierarchies(org=org)
+        raw_data = self.get_all_hierarchies(org_id=org_id)
 
         for data in raw_data:
 
@@ -1107,10 +1124,12 @@ class ApiManager:
 
         return raw_data
 
-    def get_single_hierarchy(self, org, hierarchy):
+    @single_org
+    def get_single_hierarchy(self, org_id=None, *, hierarchy):
         """
         Method to retrieve all the data form a single hierarchy and remove unnecessary data to be displayed on the console
-        :param org: Organization id where the org is stored
+
+        :param org_id: Organization id where the org is stored
         :param hierarchy: Hierarchy id to be retrieved
         :return:
         """
@@ -1120,7 +1139,7 @@ class ApiManager:
             ]
 
             raw_data = self.hierarchies.get_hierarchy(
-                org_id=org,
+                org_id=org_id,
                 hierarchy_id=hierarchy
             )["config"]
 
@@ -1134,23 +1153,27 @@ class ApiManager:
         except Exception as error:
             raise error
 
-    def get_all_hierarchies(self, org):
+    @single_org
+    def get_all_hierarchies(self, org_id=None):
         """
         Method to retrieve all the organization on a given org
-        :param org: Organization id where the org is stored
+
+        :param org_id: Organization id where the org is stored
         :return:
         """
         try:
             return self.hierarchies.get_all_hierarchies(
-                org_id=org
+                org_id=org_id
             )
         except Exception as error:
             raise error
 
-    def create_hierarchy(self, org, name, levels=None, attribute_names=None, private=False):
+    @single_org
+    def create_hierarchy(self, org_id=None, *, name, levels=None, attribute_names=None, private=False):
         """
         Method to create a new hierarchy on the given org
-        :param org: Organization id where the org would be saved
+
+        :param org_id: Organization id where the org would be saved
         :param name: String name of the new hierarchy
         :param levels: Array containing the level names
         :param attribute_names:
@@ -1159,7 +1182,7 @@ class ApiManager:
         """
         try:
             return self.hierarchies.create_hierarchy(
-                org_id=org,
+                org_id=org_id,
                 name=name,
                 levels=levels if levels is not None else [],
                 attribute_names=attribute_names,
@@ -1168,16 +1191,18 @@ class ApiManager:
         except Exception as error:
             raise error
 
-    def export_hierarchy(self, org, hierarchy):
+    @single_org
+    def export_hierarchy(self, org_id=None, *, hierarchy):
         """
         Method to extract the necessary information to export a hierarchy
-        :param org: organization id where the hierarchy currently is stored
+
+        :param org_id: organization id where the hierarchy currently is stored
         :param hierarchy: hierarchy id to be exported
         :return:
         """
         try:
             data = self.get_single_hierarchy(
-                org=org,
+                org_id=org_id,
                 hierarchy=hierarchy
             )
 
@@ -1193,10 +1218,12 @@ class ApiManager:
         except Exception as error:
             raise error
 
-    def import_hierarchy(self, org, content):
+    @single_org
+    def import_hierarchy(self, org_id=None, *, content):
         """
         Method to import a hierarchy, this should be used with the output of the export hierarchy
-        :param org: organization id where the new hierarchy will be saved
+
+        :param org_id: organization id where the new hierarchy will be saved
         :param content: json object containing hierarchy data
         :return:
         """
@@ -1205,7 +1232,7 @@ class ApiManager:
             if "name" in data:
 
                 new_h = self.create_hierarchy(
-                    org=org,
+                    org_id=org_id,
                     name=data["name"]
                 )
 
@@ -1215,12 +1242,13 @@ class ApiManager:
                     levels = data["levels"]
 
                     for i in range(0, len(levels.keys())):
-
                         self.hierarchies.add_level(
-                            org_id=org,
+                            org_id=org_id,
                             hierarchy_id=hierarchy_id,
                             level_name=levels[str(i)]
                         )
 
+                return new_h
+
         except Exception as error:
             raise error
