@@ -22,6 +22,7 @@ import uuid
 from unify.apirequestsmng import ApiRequestManager
 from unify.properties import Properties
 from unify.properties import ClusterSetting
+from unify.helpers.SingleOrg import single_org
 
 
 class OrgAdmin(ApiRequestManager):
@@ -35,7 +36,7 @@ class OrgAdmin(ApiRequestManager):
     def __exit__(self, exc_type, exc_val, exc_tb):
         pass
 
-    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING)):
+    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING), org_id=None):
         """
         Class constructor
 
@@ -45,7 +46,7 @@ class OrgAdmin(ApiRequestManager):
         :type props: class:`unify.properties.Properties`
         """
 
-        super().__init__(cluster=cluster, props=props)
+        super().__init__(cluster=cluster, props=props, org_id=org_id)
 
         try:
 
@@ -60,7 +61,8 @@ class OrgAdmin(ApiRequestManager):
         except Exception as error:
             raise error
 
-    def get_org_info(self, org_id):
+    @single_org
+    def get_org_info(self, org_id=None):
         """
         Retrieves the org metadata
 
@@ -69,21 +71,23 @@ class OrgAdmin(ApiRequestManager):
         :return: List of information on the organization
         """
 
-        self.verify_properties()
+        self.verify_properties(cluster_name=self.cluster)
 
         jobs = self.session.get(
             self.org_info_url.format(org_id),
             headers=self.build_header(
-                aut_token=self.props.get_auth_token(),
+                aut_token=self.props.get_auth_token(cluster=self.cluster),
                 org_id=org_id,
                 others=self.content_type_header)
         )
 
         return json.loads(jobs.content), jobs.status_code
 
-    def submit_sensor_diagnostics(self, org_id, content):
+    @single_org
+    def submit_sensor_diagnostics(self, org_id=None, *, content):
         """
         Create a request to the sensor diagnostics endpoint
+
         :param org_id: Organization where the sensor diagnostics will be submitted
         :param content: sensot diagnostics data
         :return: Results of the sensor diagnostics request
@@ -144,7 +148,8 @@ class OrgAdmin(ApiRequestManager):
 
             raise error
 
-    def delete_organization(self, org_id):
+    @single_org
+    def delete_organization(self, org_id=None):
         """
         Deletes the org that matched the given org id
 
@@ -170,7 +175,8 @@ class OrgAdmin(ApiRequestManager):
         except Exception as error:
             raise error
 
-    def invite_user(self, org_id, email, name, role):
+    @single_org
+    def invite_user(self, org_id=None, *, email, name, role):
         """
         Adds an user to the given org
 
@@ -210,7 +216,8 @@ class OrgAdmin(ApiRequestManager):
 
             raise error
 
-    def invite_machine_user(self, org_id, id, password, fullname, role):
+    @single_org
+    def invite_machine_user(self, org_id=None, *, id, password, fullname, role):
         """
         Invites a machine user
 
@@ -272,10 +279,11 @@ class OrgAdmin(ApiRequestManager):
         except Exception as error:
             raise error
 
-    def rename_organization(self, org, new_name):
-
+    @single_org
+    def rename_organization(self, org_id=None, *, new_name):
         """
         Rename an existing organization
+
         :param org: Org id to rename
         :param new_name: New name to set to the org
         :return:
@@ -285,9 +293,9 @@ class OrgAdmin(ApiRequestManager):
             others=self.content_type_header
         )
 
-        organization_url = self.org_api_url.format(org)
+        organization_url = self.org_api_url.format(org_id)
 
-        payload = {"id": org, "name": new_name}
+        payload = {"id": org_id, "name": new_name}
 
         try:
 
