@@ -91,6 +91,14 @@ class Pipelines(ApiRequestManager):
             self.apply_map_attributes_url = self.props.get_remote(
                 self.cluster) + "tags/org/{}/pipelines/{}/components/{}/map-attribute-rules"
 
+            self.count_endpoint = self.props.get_remote(self.cluster) + "tags/org/{}/pipelines/{}/flows/{}/count"
+
+            self.distinct_count_values_url = self.props.get_remote(
+                self.cluster) + 'tags/org/{}/pipelines/{}/flows/{}/distinctValuesWithCount'
+
+            self.distinct_values_url = self.props.get_remote(
+                self.cluster) + 'tags/org/{}/pipelines/{}/flows/{}/distinctValues'
+
         except Exception as error:
             raise error
 
@@ -235,7 +243,7 @@ class Pipelines(ApiRequestManager):
         raise Exception(repr(update_pipeline_request.content))
 
     @single_org
-    def download_map_attributes(self, org_id=None, pipeline_id=None, component_id=None):
+    def download_map_attributes(self, org_id=None, *, pipeline_id, component_id):
         """
         Downloads the map attributes data from the given pipeline
 
@@ -422,6 +430,56 @@ class Pipelines(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
+    @single_org
+    def delete_pipeline(self, org_id=None, *, pipeline_id):
+        """
+        Deletes the given pipeline
+        :param org_id:
+        :param pipeline_id:
+        :return:
+        """
+
+        header = self.build_header(
+            others=self.content_type_header,
+            org_id=org_id
+        )
+
+        result = self.session.delete(
+            self.pipelines_url_v2.format(org_id, pipeline_id),
+            headers=header
+        )
+
+        if result.status_code in [200, 201, 202]:
+            return json.loads(result.content)
+
+        raise Exception(repr(result.content))
+
+    @single_org
+    def unpublish_pipeline(self, org_id=None, *, pipeline_id):
+        """
+        Unpublishes a pipeline from graph v1
+        :param org_id:
+        :param pipeline_id:
+        :return:
+        """
+        header = self.build_header(
+            others=self.content_type_header,
+            org_id=org_id
+        )
+
+        update_payload = {"status": "draft"}
+
+        response = self.session.put(
+            self.pipelines_url_v2.format(org_id, pipeline_id),
+            headers=header,
+            data=json.dumps(update_payload)
+        )
+
+        if response.status_code in [200, 201, 202]:
+            return json.loads(response.content)
+
+        raise Exception(repr(response.content))
+
     @single_org
     def get_map_attribute_rules(self, org_id=None, *, pipeline_id, component):
         """
@@ -557,3 +615,211 @@ class Pipelines(ApiRequestManager):
             org_id=org_id,
             pipeline_name=pipeline_name
         )["pipeline_id"] is not None
+
+    @single_org
+    def update_pipeline_metadata(self, org_id=None, *, pipeline_id, name, description="", facets=None):
+        """
+        Method to update a pipeline's metadata
+        :param org_id: org id where the pipeline is stored
+        :param pipeline_id: id of the pipeline to be edited
+        :param name: new pipeline name
+        :param description: description to be added
+        :param facets:
+        :return:
+        """
+
+        headers = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        self.get_pipeline(
+            org_id=org_id,
+            pipeline_id=pipeline_id
+        )
+
+        body = {
+            "name": name,
+            "description": description,
+            "facets": [] if facets is None else facets
+        }
+
+        url = self.pipelines_url_v2.format(org_id, pipeline_id)
+
+        response = self.session.put(
+            url,
+            json=body,
+            headers=headers
+        )
+
+        if response.status_code in [200, 201, 202]:
+            return json.loads(response.content)
+
+        raise Exception(repr(response.content))
+
+    @single_org
+    def preview_flow(self, org_id=None, *, pipeline_id, flow_id):
+
+        """
+        Previews the given flow with default ordering
+        :param org_id:
+        :param pipeline_id:
+        :param flow_id:
+        :return:
+        """
+
+        header = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        cookies = {'_gid': 'GA1.1.1649742346.1580648966'}
+
+        schema_url = self.flow_preview_url.format(org_id, pipeline_id, flow_id)
+
+        flow_data = self.session.get(
+            schema_url,
+            headers=header,
+            cookies=cookies
+        )
+
+        if flow_data.status_code in [200, 201, 202]:
+            return json.loads(flow_data.content)
+
+        raise Exception(repr(flow_data.content))
+
+    @single_org
+    def preview_flow_by_column(self, org_id=None, *, pipeline_id, flow_id, sort_column):
+
+        """
+        Previews the given flow ordered by the column name give
+        :param org_id:
+        :param pipeline_id:
+        :param flow_id:
+        :param sort_column:
+        :return:
+        """
+
+        header = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        schema_url = self.preview_data_pipeline.format(org_id, pipeline_id, flow_id, sort_column)
+
+        request = self.session.get(schema_url, headers=header)
+
+        if request.status_code in [200, 201, 202]:
+            return json.loads(request.content)
+
+        raise Exception(repr(request.content))
+
+    @single_org
+    def flow_row_count(self, org_id=None, *, pipeline_id=None, flow_id=None):
+
+        """
+        Retrieves the number of rows the given flow contains
+        :param org_id:
+        :param pipeline_id:
+        :param flow_id:
+        :return:
+        """
+
+        header = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        schema_url = self.count_endpoint.format(org_id, pipeline_id, flow_id)
+
+        request = self.session.get(schema_url, headers=header)
+
+        if request.status_code in [200, 201, 202]:
+            return json.loads(request.content)
+
+        raise Exception(repr(request.content))
+
+    @single_org
+    def publish_pipeline(self, org_id=None, *, pipeline_id):
+
+        """
+        Published pipeline
+        :param org_id:
+        :param pipeline_id:
+        :return:
+        """
+
+        header = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        run_url = self.run_pipeline_url.format(org_id, pipeline_id)
+
+        params = [("parquet", True)]
+
+        run_request = self.session.post(run_url, headers=header, params=params)
+
+        if run_request.status_code in [200, 201, 202]:
+            return json.loads(run_request.content)
+
+        raise Exception(repr(run_request.content))
+
+    @single_org
+    def get_flow_distinct_values(self, org_id=None, *, pipeline_id, flow_id, col, sort_key, count=False):
+        """
+        Returns distinct values from a given flow, if count is true, it will return the count per distinct value
+        :param org_id:
+        :param pipeline_id:
+        :param flow_id:
+        :param col:
+        :param sort_key:
+        :param count:
+        :return:
+        """
+        headers = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        if count:
+            get_distinct_vals = self.distinct_count_values_url.format(org_id, pipeline_id, flow_id)
+        else:
+            get_distinct_vals = self.distinct_values_url.format(org_id, pipeline_id, flow_id)
+
+        data = [("col", col), ("sortKey", sort_key), ("sortDir", "ASC")]
+
+        result = self.session.get(get_distinct_vals, headers=headers, params=data)
+
+        if result.status_code in [200, 201, 202]:
+            return json.loads(result.content)
+
+        raise Exception(repr(result.content))
+
+    @single_org
+    def autosync_pipeline(self, org_id=None, *, pipeline_id, autoSyncEnabled=True):
+
+        """
+        Changes the autosync status of a pipeline
+        :param org_id:
+        :param pipeline_id:
+        :param autoSyncEnabled:
+        :return:
+        """
+        headers = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        payload = {"autoSyncEnabled": autoSyncEnabled}
+
+        post_pipeline_request = self.session.put(
+            self.autosync_url.format(org_id, pipeline_id),
+            headers=headers,
+            data=json.dumps(payload)
+        )
+
+        if post_pipeline_request.status_code in [200, 201, 202]:
+            return json.loads(post_pipeline_request.content)
+
+        raise Exception(repr(post_pipeline_request.content))
