@@ -93,6 +93,12 @@ class Sources(ApiRequestManager):
 
             self.get_commit = self.commit_data_set_url + "/{}"
 
+            self.preview_source_url = self.props.get_remote(
+                self.cluster) + "tags/org/{}/datasets/{}/preview"
+
+            self.dataset_info_url = self.props.get_remote(
+                self.cluster) + "tags/org/{}/pipelines/v2/datasets"
+
         except Exception as error:
             raise error
 
@@ -200,7 +206,6 @@ class Sources(ApiRequestManager):
                 convert_to_parquet=convert_to_parquet,
                 encoding=encoding
             )
-            print(dataset_data[aux_name])
 
             Wait().until(
                 self.is_commit_completed,
@@ -308,7 +313,7 @@ class Sources(ApiRequestManager):
                     os.close(file_dir)
 
                 except Exception as err:
-                    return repr(err)
+                    print("skipping {}".format(repr(err)))
 
         return dataset_data
 
@@ -345,7 +350,7 @@ class Sources(ApiRequestManager):
         if file_path is None:
             raise Exception("File Path must not be None")
 
-        content = open(file_path, "r+").read()
+        content = open(file_path, "rb").read().decode(encoding)
 
         return self.create_api_data_set_with_content(
             name=name,
@@ -562,7 +567,7 @@ class Sources(ApiRequestManager):
     @single_org
     def overwrite_dataset(
             self, org_id=None, *, data_set_id, file_path, group_id=None,
-            format="csv", convert_to_parquet="false"):
+            format="csv", convert_to_parquet="false", encoding="utf-8 "):
 
         """
         Overwrites the contents of the given dataset with new content.
@@ -579,6 +584,8 @@ class Sources(ApiRequestManager):
         :type format: str, optional
         :param convert_to_parquet: Flag to convert file to parquet
         :type convert_to_parquet: bool, optional
+        :param encoding: Encoding of the file
+        :type encoding: int or str
         :return:
         """
         response = {}
@@ -590,13 +597,14 @@ class Sources(ApiRequestManager):
 
         name = "overwirte{}".format(int(time.time()))
 
-        response["stage"] = self.stage_file(
+        response["stage"] = self.stage_data(
             name=name,
             org_id=org_id,
             file_path=file_path,
             group_id=group_id,
             format=format,
-            convert_to_parquet=convert_to_parquet
+            convert_to_parquet=convert_to_parquet,
+            encoding=encoding
         )
 
         response["append"] = self.append_command(
@@ -880,7 +888,7 @@ class Sources(ApiRequestManager):
         test_request = self.session.post(
             self.stage_file_url,
             headers=headers,
-            data=file_data,
+            data=file_data.encode(encoding),
             params=payload_data
         )
 
@@ -909,7 +917,7 @@ class Sources(ApiRequestManager):
         schema_request = self.session.post(
             self.post_data_set_schema_url,
             headers=headers,
-            data=schema_data
+            data=schema_data.encode(encoding)
         )
 
         if schema_request.status_code == 200:
@@ -965,16 +973,15 @@ class Sources(ApiRequestManager):
         raise Exception(repr(post_upload_pitag.content))
 
     @single_org
-    def static_file_upload(self, name, content, org_id=None):
+    def static_file_upload(self, name, content, org_id=None, params=None):
         """
-        Uploads a static file with content.
-
         :param name: Dataset name to be created
         :type name: str
         :param content: Dataset content stored in a variable
         :type content: str
         :param org_id: Org where the dataset will be created
         :type org_id: str
+        :param params: Additional http parameters
         :return:
         """
 
@@ -988,6 +995,11 @@ class Sources(ApiRequestManager):
 
         files = {'file': open(content, "rb")}
 
+        if params is not None:
+            for tup in params:
+                if len(tup) == 2:
+                    query_strings[tup[0]] = tup[1]
+
         post_upload_file = self.session.post(
             static_file_upload_url.format(org_id),
             headers=headers,
@@ -1015,28 +1027,19 @@ class Sources(ApiRequestManager):
             others=self.delete_content_type_header
         )
 
-        if self.evergreen_enabled:
+        query_strings = {
+            "ean.orgs": org_id,
+            "_fields": "schema,ean.ready,ean.source_type,ean.facets,ean.description,ean.dataArchiveServerName"
+        }
 
-            query_strings = {
-                "ean.orgs": org_id,
-                "_fields": "schema,ean.ready,ean.source_type,ean.facets,ean.table,ean.description,ean.dataArchiveServerName"
-            }
+        get_sources_request = self.session.get(
+            self.labeling_sources_2,
+            headers=header,
+            params=query_strings
+        )
 
-            get_sources_request = self.session.get(
-                self.labeling_sources_2,
-                headers=header,
-                params=query_strings
-            )
-
-            content = json.loads(get_sources_request.content.decode('utf8'))
-        else:
-
-            get_sources_request = self.session.get(self.sources_url.format(org_id), headers=header)
-
-            content = json.loads(get_sources_request.content)
-
-        if get_sources_request.status_code == 200:
-            return content
+        if get_sources_request.status_code in [200, 201, 202]:
+            return json.loads(get_sources_request.content.decode('utf8'))
 
         raise Exception(repr(get_sources_request.content))
 
@@ -1090,7 +1093,6 @@ class Sources(ApiRequestManager):
             aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
-
         )
 
         delete_request = self.session.delete(
@@ -1105,3 +1107,86 @@ class Sources(ApiRequestManager):
             return json.loads(delete_request.content)
 
         raise Exception(json.loads(delete_request.content))
+
+    @single_org
+    def preview_dataset(self, org_id=None, *, dataset_id, page_num=1):
+
+        """
+        Preview the content of the dataset id give, page_num is the pagination of the given dataset
+        :param org_id:
+        :param dataset_id:
+        :param page_num:
+        :return:
+        """
+
+        headers = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            org_id=org_id,
+            others=self.content_type_header
+        )
+
+        data = [("pageNum", page_num)]
+
+        get_response = self.session.get(
+            self.preview_source_url.format(org_id, dataset_id),
+            headers=headers,
+            params=data
+        )
+
+        if get_response.status_code in [200, 201]:
+            return json.loads(get_response.content)
+
+        raise Exception(json.loads(get_response.content))
+
+    @single_org
+    def get_dataset_info(self, org_id=None, *, dataset_id):
+
+        """
+        return metdadata of the desired dataset
+        :param org_id:
+        :param dataset_id:
+        :return:
+        """
+
+        headers = self.build_header(
+            aut_token=self.props.get_auth_token(cluster=self.cluster),
+            org_id=org_id,
+            others=self.content_type_header
+        )
+
+        data = [("dataset_id", dataset_id)]
+
+        get_response = self.session.get(
+            self.dataset_info_url.format(org_id),
+            headers=headers,
+            params=data
+        )
+
+        if get_response.status_code in [200, 201]:
+            return json.loads(get_response.content)
+
+        raise Exception(json.loads(get_response.content))
+
+    @single_org
+    def upload_spreadsheet(self, name=None, file_path=None, org_id=None, sheet_name=None):
+
+        """
+        :param name:
+        :param file_path:
+        :param org_id:
+        :param sheet_name: Specify the spreadsheet name where the data is located
+        :return:
+        """
+        if sheet_name is None:
+            return self.static_file_upload(
+                name=name,
+                content=file_path,
+                org_id=org_id
+            )
+        else:
+            return self.static_file_upload(
+                name=name,
+                content=file_path,
+                org_id=org_id,
+                params=[('sheetName', sheet_name)]
+            )
